@@ -1,10 +1,8 @@
 import requests
-import shutil
 import os
 import platform
 import subprocess
 import re
-import time
 import zipfile
 from pathlib import Path
 from bs4 import BeautifulSoup
@@ -16,11 +14,10 @@ from .utils import Util
 
 OSNAME = platform.system()
 init()
-util = Util()
 DRIVER = Path(__file__).resolve().absolute().parent / "driver"
 
 
-class Download:
+class Download(Util):
     """
     It will get the installed Chrome driver and based on the operating system
     it will download the compatible chromedriver.
@@ -33,6 +30,44 @@ class Download:
     else:
         system = "mac"
 
+    def update_binary(self, path):
+        word = "cdc_".encode()
+        new = "tch_".encode()
+        while True:
+            string = b""
+            Flag = 0
+            with open(path, 'r+b') as file:
+                pos = 0
+                data = string = file.read(1)
+                while data:
+                    data = file.read(1)
+                    if data == b" ":
+                        if word in string:
+                            new_tring = string.decode().replace(word.decode(), new.decode())
+                            file.seek(pos)
+                            file.write(new_tring.encode())
+                            Flag = 1
+                            break
+                        else:
+                            pos = file.tell()
+                            data = string = file.read(1)
+                    else:
+                        string += data
+                        continue
+            if not Flag:
+                break
+
+    def remove_signature_in_javascript(self, path):
+        if OSNAME == "Windows":
+            os.chmod(path, 755)
+        else:
+            subprocess.Popen(f"sudo chmod 777 {path}", stdout=subprocess.PIPE, shell=True)
+        with open(path, "r", errors="ignore") as chrome:
+            content = chrome.read()
+        content = content.replace("cdc_", "tch_")   
+        self.update_binary(path)
+
+
     def check_installed_chrome_version(self):
         try:
             if OSNAME == "Windows":
@@ -80,7 +115,7 @@ class Download:
                 + colored(installed_chrome_version, "blue")
                 + " installed."
             )
-            util.update_chrome_driver_config(version=installed_chrome_version)
+            self.update_chrome_driver_config(version=installed_chrome_version)
             return installed_chrome_version
 
     def get_chrome_driver_download_link(self, version):
@@ -107,7 +142,7 @@ class Download:
         with requests.get(download_link, stream=True, headers=headers) as r:
             print("downloading " + colored(f"{chrome_file_name}", "blue") + " ...")
             with open(os.path.join(DRIVER, chrome_file_name), "wb") as f:
-                shutil.copyfileobj(r.raw, f)
+                shself.copyfileobj(r.raw, f)
         
         return chrome_driver_file
 
@@ -121,7 +156,7 @@ class Download:
         os.remove(path)
         print(colored("[+]", "green") + " Chrome driver has been installed.")
         chromedriver_path = os.path.join(DRIVER, filename)
-        util.update_chrome_driver_config(chromedriver=chromedriver_path)
+        self.update_chrome_driver_config(chromedriver=chromedriver_path)
         
-
+        self.remove_signature_in_javascript(chromedriver_path)
         return filename
\ No newline at end of file
